@@ -1,9 +1,24 @@
 # -*- coding: utf-8 -*-
 import datetime
+import south
 from south.db import db
 from south.v2 import SchemaMigration
 from django.db import models
 
+if south.__version__ == '0.8.3':
+    raise Exception(
+        'Due to a bug in South 0.8.3, migrations cannot be run. Please '
+        'upgrade to South 0.8.4 or later using `pip install -U South` and '
+        'run the migrations again.'
+    )
+
+
+from ..utils import get_user_model
+User = get_user_model()
+
+user_orm_label = '%s.%s' % (User._meta.app_label, User._meta.object_name)
+user_model_label = '%s.%s' % (User._meta.app_label, User._meta.module_name)
+user_ptr_name = '%s_ptr' % User._meta.object_name.lower()
 
 class Migration(SchemaMigration):
 
@@ -48,7 +63,7 @@ class Migration(SchemaMigration):
         # Adding model 'Subscription'
         db.create_table('newsletter_subscription', (
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
-            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], null=True, blank=True)),
+            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm[user_orm_label], null=True, blank=True)),
             ('name_field', self.gf('django.db.models.fields.CharField')(max_length=30, null=True, db_column='name', blank=True)),
             ('email_field', self.gf('django.db.models.fields.EmailField')(db_index=True, max_length=75, null=True, db_column='email', blank=True)),
             ('ip', self.gf('django.db.models.fields.IPAddressField')(max_length=15, null=True, blank=True)),
@@ -163,8 +178,8 @@ class Migration(SchemaMigration):
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
         },
-        'auth.user': {
-            'Meta': {'object_name': 'User'},
+        user_model_label: {
+            'Meta': {'object_name': User.__name__, 'db_table': "'%s'" % User._meta.db_table},
             'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
             'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
             'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
@@ -254,7 +269,7 @@ class Migration(SchemaMigration):
             'subscribed': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'db_index': 'True'}),
             'unsubscribe_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
             'unsubscribed': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'db_index': 'True'}),
-            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True', 'blank': 'True'})
+            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['%s']" % user_orm_label, 'null': 'True', 'blank': 'True'})
         },
         'sites.site': {
             'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
@@ -264,4 +279,4 @@ class Migration(SchemaMigration):
         }
     }
 
-    complete_apps = ['newsletter']
\ No newline at end of file
+    complete_apps = ['newsletter']
